@@ -1,6 +1,6 @@
 import socket
 
-from manage.manage import main
+from .manage.manage import main
 
 
 def get_my_ip():
@@ -17,6 +17,6 @@ def get_my_ip():
 
 ip = str(get_my_ip())
 
-main('makemigrations')
-main('migrate')
-main('runserver', ip + ':8000')
+main('makemigrations data')
+main('migrate data')
+main('runserver ' + ip + ':8000')
