@@ -1,6 +1,10 @@
+import json
+
 from django.core import serializers as django_serializers
 from django.http import JsonResponse, HttpResponse, QueryDict
 from django.shortcuts import render
+from django.utils.decorators import method_decorator
+from django.views.decorators.csrf import ensure_csrf_cookie, csrf_exempt
 from polymorphic.models import PolymorphicTypeInvalid
 from rest_framework import viewsets, renderers
 from rest_framework.response import Response
@@ -204,7 +208,7 @@ class HardwareViewSet(viewsets.ModelViewSet):
 
     def postHardware(request):
         # request should be ajax and method should be POST.
-        if request.is_ajax and request.method == "POST":
+        if request.is_ajax() and request.method == "POST":
             # get the form data
             hardware_form = HardwareForm(request.POST)
             hardware_type = request.POST['type']
@@ -229,7 +233,18 @@ class HardwareViewSet(viewsets.ModelViewSet):
             else:
                 # some form errors occured.
                 return JsonResponse({"error": hardware_form.errors}, status=400)
+        elif request.method == "POST":
+            import json
+            body_json = json.loads(request.body.decode('utf-8'))
+            pi_pico = PiPico()
+            pi_pico.id = body_json['id']
+            pi_pico.type = body_json['type']
+            pi_pico.hub = Hub.objects.get(pk=body_json['hub'])
+            pi_pico.pi_gpio_interrupt = 1
+            pi_pico.save()
+            ser_instance = django_serializers.serialize('json', [pi_pico, ])
 
+            return JsonResponse({"instance": ser_instance}, status=200)
         # some error occured
         return JsonResponse({"error": ""}, status=400)
 
@@ -518,9 +533,10 @@ class ChannelViewSet(viewsets.ModelViewSet):
     def retrieve(self, request, *args, **kwargs):
         print('retrieve')
         print(str(request.path_info))
-        hardware_io_type_form = HardwareIOTypeForm(initial={'parent_hardware': Channel.objects.get(**kwargs).hardware.id,
-                                                            'child_channel': Channel.objects.get(**kwargs).id,
-                                                            'hub': Channel.objects.get(**kwargs).hub.id})
+        hardware_io_type_form = HardwareIOTypeForm(
+            initial={'parent_hardware': Channel.objects.get(**kwargs).hardware.id,
+                     'child_channel': Channel.objects.get(**kwargs).id,
+                     'hub': Channel.objects.get(**kwargs).hub.id})
         hardware_ios = Channel.objects.get(**kwargs).hardwareio_set.all()
 
         channel = Channel.objects.get(**kwargs)
@@ -534,15 +550,13 @@ class ChannelViewSet(viewsets.ModelViewSet):
         else:
             return super(ChannelViewSet, self).retrieve()
 
-    def listIO(self,channel_id):
+    def listIO(self, channel_id):
         print('list io')
         hardware_ios = Channel.objects.get(pk=channel_id).hardwareio_set.all()
         serialized_hardware_ios = HardwareIOSerializer(many=True).to_representation(hardware_ios)
 
         return JsonResponse(serialized_hardware_ios, status=200, safe=False)
 
-
-
     def updateChannel(request):
         # request should be ajax and method should be POST.
         if request.is_ajax and request.method == "PATCH":
@@ -599,6 +613,10 @@ class HubViewSet(viewsets.ModelViewSet):
         serialized_accessories = AccessorySerializer(many=True).to_representation(accessories)
         return JsonResponse(serialized_accessories, status=200, safe=False)
 
+    def about(self, *args, **kwargs):
+        api_about = {}
+        api_about['isAPI'] = True
+        return JsonResponse(api_about, status=200, safe=False)
 
     def list(self, request, *args, **kwargs):
         print('list')
@@ -609,6 +627,7 @@ class HubViewSet(viewsets.ModelViewSet):
             return Response({"form": form, "hubs": hubs}, template_name='hubs.html')
         return response
 
+    @csrf_exempt
     def retrieve(self, request, *args, **kwargs):
 
         if request.accepted_renderer.format == 'html':
@@ -627,9 +646,10 @@ class HubViewSet(viewsets.ModelViewSet):
             hub_data = HubSerializer(instance=hub).to_representation(hub)
             return JsonResponse(hub_data, status=200)
 
-    def postHub(request):
+
+    def postHub( request):
         # request should be ajax and method should be POST.
-        if request.is_ajax and request.method == "POST":
+        if request.is_ajax() and request.method == "POST":
             # get the form data
             form = HubForm(request.POST)
             # save the data and after fetch the object in instance
@@ -644,6 +664,18 @@ class HubViewSet(viewsets.ModelViewSet):
             else:
                 # some form errors occured.
                 return JsonResponse({"error": form.errors}, status=400)
+        elif request.method == "POST":
+            import json
+            body_json = json.loads(request.body.decode('utf-8'))
+            hub = Hub()
+            hub.id = body_json['id']
+            hub.ip = body_json['ip']
+            hub.display_name = body_json['display_name']
+            hub.aid = body_json['aid']
+            hub.save()
+            ser_instance = django_serializers.serialize('json', [hub, ])
+
+            return JsonResponse({"instance": ser_instance}, status=200)
 
         # some error occured
         return JsonResponse({"error": ""}, status=400)
@@ -652,12 +684,11 @@ class HubViewSet(viewsets.ModelViewSet):
 def index(request):
     context = {'title': 'HomeHub'}
     return render(request, 'home.html', context)
+
+
 #
 
 
-
-
-
 class IOViewSet(viewsets.ModelViewSet):
     queryset = HardwareIO.objects.all()
     serializer_class = HardwareIOSerializer
@@ -685,9 +716,6 @@ class IOViewSet(viewsets.ModelViewSet):
         if hardware_io_type == PiGPIO:
             hardware_form = PiGpioForm(instance=instance)
 
-
-
-
         if request.accepted_renderer.format == 'html':
             return Response(
                 {"hardware_io_form": hardware_form},
@@ -700,7 +728,7 @@ class IOViewSet(viewsets.ModelViewSet):
         if request.is_ajax and request.method == "PATCH":
             # get the form data
             form = HardwareIoForm(instance=Channel.objects.get(pk=QueryDict(request.body)['id']),
-                               data=QueryDict(request.body))
+                                  data=QueryDict(request.body))
 
             # save the data and after fetch the object in instance
             if form.is_valid():
@@ -723,7 +751,7 @@ class IOViewSet(viewsets.ModelViewSet):
         if request.is_ajax and request.method == "DELETE":
             # get the form data
             form = HardwareIoForm(instance=HardwareIO.objects.get(pk=QueryDict(request.body)['id']),
-                               data=QueryDict(request.body))
+                                  data=QueryDict(request.body))
             hardware_io = HardwareIO.objects.get(
                 pk=QueryDict(request.body)['id'])  # save the data and after fetch the object in instance
             hardware_io.delete()
